@@ -13,16 +13,17 @@ from pathlib import Path
 
 import graphviz as gv
 import networkx as nx
+import pendulum
 from arg_services.graph.v1 import graph_pb2
 from arguebuf.models import Userdata
 from arguebuf.models.analyst import Analyst
-from arguebuf.models.edge import Edge
+from arguebuf.models.edge import Edge, EdgeStyle
 from arguebuf.models.metadata import Metadata
 from arguebuf.models.node import AtomNode, Attack, Node, Rephrase, SchemeNode, Support
 from arguebuf.models.participant import Participant
 from arguebuf.models.reference import Reference
 from arguebuf.models.resource import Resource
-from arguebuf.schema import aif, aml, ova, sadface
+from arguebuf.schema import aif, aml, argdown_json, ova, sadface
 from arguebuf.services import dt, utils
 from arguebuf.services.utils import ImmutableDict, ImmutableSet
 from google.protobuf.json_format import MessageToDict, ParseDict
@@ -767,6 +768,59 @@ class Graph:
 
         return g
 
+    @classmethod
+    def from_argdown_json(
+        cls,
+        obj: argdown_json.Graph,
+        name: t.Optional[str] = None,
+        atom_class: t.Type[AtomNode] = AtomNode,
+        scheme_class: t.Type[SchemeNode] = SchemeNode,
+        edge_class: t.Type[Edge] = Edge,
+        nlp: t.Optional[t.Callable[[str], t.Any]] = None,
+    ) -> Graph:
+        """Generate Graph structure from JSON Argdown argument graph file
+        (reference: https://argdown.org/).
+        """
+        g = cls(name)
+
+        timestamp = pendulum.now()
+
+        # Every node in obj["nodes"] is a atom node
+        for argdown_node in obj["map"]["nodes"]:
+            node = atom_class.from_argdown_json(argdown_node, nlp)
+
+            if node:
+                g.add_node(node)
+
+        for argdown_edge in obj["map"]["edges"]:
+            if edge := edge_class.from_argdown_json(argdown_edge, g._nodes):
+                g.add_edge(edge)
+                if argdown_edge["relationType"] == "support":
+                    scheme = Support.DEFAULT
+                elif argdown_edge["relationType"] == "attack":
+                    scheme = Attack.DEFAULT
+                elif argdown_edge["relationType"] == "contradictory":
+                    scheme = Attack.DEFAULT
+                elif argdown_edge["relationType"] == "undercut":
+                    scheme = Support.DEFAULT
+                else:
+                    scheme = Support.DEFAULT
+                # create scheme_node for edge
+                scheme_node = SchemeNode(
+                    metadata=Metadata(timestamp, timestamp),
+                    scheme=scheme,
+                )
+                g.add_node(scheme_node)
+
+                # create edge from source to scheme_node and an edge from scheme_node to target
+                g.add_edge(Edge(edge.source, scheme_node))
+                g.add_edge(Edge(scheme_node, edge.target))
+
+        metadata = Metadata(timestamp, timestamp)
+        g.metadata = metadata
+
+        return g
+
     @classmethod
     def from_aif(
         cls,
@@ -1347,6 +1401,7 @@ class Graph:
         graph_attr: t.Optional[t.Mapping[str, str]] = None,
         node_attr: t.Optional[t.Mapping[str, str]] = None,
         edge_attr: t.Optional[t.Mapping[str, str]] = None,
+        edge_style: t.Optional[EdgeStyle] = None,
     ) -> gv.Digraph:
         """Transform a Graph instance into an instance of GraphViz directed graph. Make sure that a GraphViz Executable path is set on your machine for visualization. Refer to the GraphViz library for additional information."""
         gv_margin: t.Callable[[t.Tuple[float, float]], str] = lambda x: f"{x[0]},{x[1]}"
@@ -1382,6 +1437,8 @@ class Graph:
                 "margin": "0",
                 "nodesep": str(nodesep or 0.25),
                 "ranksep": str(ranksep or 0.5),
+                "overlap": False,
+                "splines": edge_style.value if edge_style else EdgeStyle.STEP.value,
                 **graph_attr,
             },
         )
