@@ -16,7 +16,7 @@ from arguebuf.models.metadata import Metadata
 from arguebuf.models.participant import Participant
 from arguebuf.models.reference import Reference
 from arguebuf.models.resource import Resource
-from arguebuf.schema import aif, ova, sadface
+from arguebuf.schema import aif, argdown_json, ova, sadface
 from arguebuf.services import dt, utils
 
 NO_SCHEME_LABEL = "Unknown"
@@ -334,6 +334,11 @@ class Node(ABC):
     def id(self) -> str:
         return self._id
 
+    @property
+    @abstractmethod
+    def label(self) -> str:
+        """Generate a matching node label (e.g., for graphviz)"""
+
     @abstractmethod
     def color(self, major_claim: bool) -> Color:
         """Get the color used in OVA based on `category`."""
@@ -365,6 +370,15 @@ class Node(ABC):
     ) -> Node:
         """Generate Node object from SADFace Node format."""
 
+    @classmethod
+    @abstractmethod
+    def from_argdown_json(
+        cls,
+        obj: argdown_json.Node,
+        nlp: t.Optional[t.Callable[[str], t.Any]] = None,
+    ) -> Node:
+        """Import argdown"""
+
     @classmethod
     @abstractmethod
     def from_aml(
@@ -442,6 +456,10 @@ class AtomNode(Node):
 
         return utils.xstr(self.text)
 
+    @property
+    def label(self) -> str:
+        return self.plain_text
+
     @property
     def reference(self) -> t.Optional[Reference]:
         return self._reference
@@ -468,6 +486,20 @@ class AtomNode(Node):
             metadata=Metadata(timestamp, timestamp),
         )
 
+    @classmethod
+    def from_argdown_json(
+        cls,
+        obj: argdown_json.Node,
+        nlp: t.Optional[t.Callable[[str], t.Any]] = None,
+    ) -> AtomNode:
+        """Generate AtomNode object from Argdown JSON Node object."""
+        timestamp = pendulum.now()
+        return cls(
+            id=obj["id"],
+            text=utils.parse(obj["labelText"], nlp),
+            metadata=Metadata(timestamp, timestamp),
+        )
+
     @classmethod
     def from_aml(
         cls,
@@ -593,7 +625,7 @@ class AtomNode(Node):
             attrs = {}
 
         if "label" not in attrs:
-            attrs["label"] = lambda x: x.plain_text
+            attrs["label"] = lambda x: x.label
 
         g.add_node(self._id, **{key: func(self) for key, func in attrs.items()})
 
@@ -613,7 +645,7 @@ class AtomNode(Node):
     ) -> None:
         """Submethod used to export Graph object g into GV Graph format."""
         color = self.color(major_claim)
-        label = label_func(self) if label_func else self.plain_text
+        label = label_func(self) if label_func else self.label
 
         # TODO: Improve wrapping
         # https://stackoverflow.com/a/26538082/7626878
@@ -662,6 +694,18 @@ class SchemeNode(Node):
             ],
         )
 
+    @property
+    def label(self) -> str:
+        label = NO_SCHEME_LABEL
+
+        if self.scheme:
+            label = type(self.scheme).__name__
+
+            if self.scheme.value != "Default":
+                label = f"{label}: {self.scheme.value}"
+
+        return label
+
     @classmethod
     def from_sadface(
         cls,
@@ -825,6 +869,15 @@ class SchemeNode(Node):
 
         return None
 
+    @classmethod
+    def from_argdown_json(
+        cls,
+        obj: argdown_json.Node,
+        nlp: t.Optional[t.Callable[[str], t.Any]] = None,
+    ) -> SchemeNode:
+        # Currently not used
+        return SchemeNode()
+
     @classmethod
     def from_protobuf(
         cls,
@@ -890,14 +943,14 @@ class SchemeNode(Node):
             attrs = {}
 
         if "label" not in attrs:
-            attrs["label"] = _scheme_label
+            attrs["label"] = lambda x: x.label
 
         g.add_node(self._id, **{key: func(self) for key, func in attrs.items()})
 
     def color(self, major_claim: bool) -> Color:
         """Get the color used in OVA based on `category`."""
 
-        return scheme2color[type(self.scheme)] if self.scheme else Color(bg="#e9eded")
+        return scheme2color[type(self.scheme)] if self.scheme else Color(bg="#009688")
 
     def to_gv(
         self,
@@ -909,7 +962,7 @@ class SchemeNode(Node):
         """Submethod used to export Graph object g into GV Graph format."""
 
         color = self.color(major_claim)
-        label = label_func(self) if label_func else _scheme_label(self)
+        label = label_func(self) if label_func else self.label
 
         g.node(
             self._id,
@@ -918,15 +971,3 @@ class SchemeNode(Node):
             fillcolor=color.bg,
             color=color.border,
         )
-
-
-def _scheme_label(obj: SchemeNode) -> str:
-    label = NO_SCHEME_LABEL
-
-    if obj.scheme:
-        label = type(obj.scheme).__name__
-
-        if obj.scheme.value != "Default":
-            label = f"{label}: {obj.scheme.value}"
-
-    return label
